@@ -1,14 +1,9 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 1997 Robey Pointer <robeypointer@gmail.com>
-  Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
-  Copyright (C) 2009 Travis McHenry <tmchenryaz@cox.net>
+    SPDX-FileCopyrightText: 1997 Robey Pointer <robeypointer@gmail.com>
+    SPDX-FileCopyrightText: 2005 Ismail Donmez <ismail@kde.org>
+    SPDX-FileCopyrightText: 2009 Travis McHenry <tmchenryaz@cox.net>
 */
 
 #ifndef CIPHER_H
@@ -23,16 +18,16 @@ namespace Konversation
     {
         public:
             Cipher();
-            explicit Cipher(QByteArray key, QString cipherType=QString("blowfish"));
+            explicit Cipher(const QByteArray &key, const QString &cipherType=QStringLiteral("blowfish"));
             ~Cipher();
 
             QByteArray decrypt(QByteArray cipher);
             QByteArray decryptTopic(QByteArray cipher);
             bool encrypt(QByteArray& cipher);
             QByteArray initKeyExchange();
-            QByteArray parseInitKeyX(QByteArray key);
-            bool parseFinishKeyX(QByteArray key);
-            bool setKey(QByteArray key);
+            QByteArray parseInitKeyX(const QByteArray &key);
+            bool parseFinishKeyX(const QByteArray &key);
+            bool setKey(const QByteArray &key);
             QByteArray key() const { return m_key; }
             bool setType(const QString &type);
             QString type() const { return m_type; }
@@ -45,9 +40,10 @@ namespace Konversation
             //direction is true for encrypt, false for decrypt
             QByteArray blowfishCBC(QByteArray cipherText, bool direction);
             QByteArray blowfishECB(QByteArray cipherText, bool direction);
-            QByteArray b64ToByte(QByteArray text);
-            QByteArray byteToB64(QByteArray text);
+            QByteArray b64ToByte(const QByteArray &text);
+            QByteArray byteToB64(const QByteArray &text);
 
+        private:
             QCA::Initializer init;
             QByteArray m_key;
             QCA::DHPrivateKey m_tempKey;
@@ -56,6 +52,9 @@ namespace Konversation
             bool m_cbc;
 
             static QString m_runtimeError;
+
+            Q_DISABLE_COPY(Cipher)
     };
 }
+
 #endif
